/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010-2011 University of Bonn. All rights reserved.
 * Please see the LICENSE file or "Copyright notice" in builder.cpp for details.
 */

/*
 * MpqcParser_Parameters_initBasis.cpp
 *
 *  Created on: Feb 4, 2011
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <string>

#include "CodePatterns/MemDebug.hpp"

#include "MpqcParser_Parameters.hpp"


void MpqcParser_Parameters::initBasis()
{
  // list is obtained via the following shell script
  //for basis in ~/install/share/mpqc/3.0.0-alpha/basis/*.kv; do
  //  grep ": \"" $basis | awk -F":" '{print "\tBasisList["$2"].push_back(\""$1"\");"}' | tr -d \ ;
  //done

  BasisList["3-21G"].push_back("hydrogen");
  BasisList["3-21G"].push_back("helium");
  BasisList["3-21G"].push_back("lithium");
  BasisList["3-21G"].push_back("beryllium");
  BasisList["3-21G"].push_back("boron");
  BasisList["3-21G"].push_back("carbon");
  BasisList["3-21G"].push_back("nitrogen");
  BasisList["3-21G"].push_back("oxygen");
  BasisList["3-21G"].push_back("fluorine");
  BasisList["3-21G"].push_back("neon");
  BasisList["3-21G"].push_back("sodium");
  BasisList["3-21G"].push_back("magnesium");
  BasisList["3-21G"].push_back("aluminum");
  BasisList["3-21G"].push_back("silicon");
  BasisList["3-21G"].push_back("phosphorus");
  BasisList["3-21G"].push_back("sulfur");
  BasisList["3-21G"].push_back("chlorine");
  BasisList["3-21G"].push_back("argon");
  BasisList["3-21G"].push_back("potassium");
  BasisList["3-21G"].push_back("calcium");
  BasisList["3-21G"].push_back("scandium");
  BasisList["3-21G"].push_back("titanium");
  BasisList["3-21G"].push_back("vanadium");
  BasisList["3-21G"].push_back("chromium");
  BasisList["3-21G"].push_back("manganese");
  BasisList["3-21G"].push_back("iron");
  BasisList["3-21G"].push_back("cobalt");
  BasisList["3-21G"].push_back("nickel");
  BasisList["3-21G"].push_back("copper");
  BasisList["3-21G"].push_back("zinc");
  BasisList["3-21G"].push_back("gallium");
  BasisList["3-21G"].push_back("germanium");
  BasisList["3-21G"].push_back("arsenic");
  BasisList["3-21G"].push_back("selenium");
  BasisList["3-21G"].push_back("bromine");
  BasisList["3-21G"].push_back("krypton");
  BasisList["3-21G*"].push_back("hydrogen");
  BasisList["3-21G*"].push_back("helium");
  BasisList["3-21G*"].push_back("lithium");
  BasisList["3-21G*"].push_back("beryllium");
  BasisList["3-21G*"].push_back("boron");
  BasisList["3-21G*"].push_back("carbon");
  BasisList["3-21G*"].push_back("nitrogen");
  BasisList["3-21G*"].push_back("oxygen");
  BasisList["3-21G*"].push_back("fluorine");
  BasisList["3-21G*"].push_back("neon");
  BasisList["3-21G*"].push_back("sodium");
  BasisList["3-21G*"].push_back("magnesium");
  BasisList["3-21G*"].push_back("aluminum");
  BasisList["3-21G*"].push_back("silicon");
  BasisList["3-21G*"].push_back("phosphorus");
  BasisList["3-21G*"].push_back("sulfur");
  BasisList["3-21G*"].push_back("chlorine");
  BasisList["3-21G*"].push_back("argon");
  BasisList["3-21++G"].push_back("hydrogen");
  BasisList["3-21++G"].push_back("helium");
  BasisList["3-21++G"].push_back("lithium");
  BasisList["3-21++G"].push_back("beryllium");
  BasisList["3-21++G"].push_back("boron");
  BasisList["3-21++G"].push_back("carbon");
  BasisList["3-21++G"].push_back("nitrogen");
  BasisList["3-21++G"].push_back("oxygen");
  BasisList["3-21++G"].push_back("fluorine");
  BasisList["3-21++G"].push_back("neon");
  BasisList["3-21++G"].push_back("sodium");
  BasisList["3-21++G"].push_back("magnesium");
  BasisList["3-21++G"].push_back("aluminum");
  BasisList["3-21++G"].push_back("silicon");
  BasisList["3-21++G"].push_back("phosphorus");
  BasisList["3-21++G"].push_back("sulfur");
  BasisList["3-21++G"].push_back("chlorine");
  BasisList["3-21++G"].push_back("argon");
  BasisList["3-21++G*"].push_back("hydrogen");
  BasisList["3-21++G*"].push_back("helium");
  BasisList["3-21++G*"].push_back("lithium");
  BasisList["3-21++G*"].push_back("beryllium");
  BasisList["3-21++G*"].push_back("boron");
  BasisList["3-21++G*"].push_back("carbon");
  BasisList["3-21++G*"].push_back("nitrogen");
  BasisList["3-21++G*"].push_back("oxygen");
  BasisList["3-21++G*"].push_back("fluorine");
  BasisList["3-21++G*"].push_back("neon");
  BasisList["3-21++G*"].push_back("sodium");
  BasisList["3-21++G*"].push_back("magnesium");
  BasisList["3-21++G*"].push_back("aluminum");
  BasisList["3-21++G*"].push_back("silicon");
  BasisList["3-21++G*"].push_back("phosphorus");
  BasisList["3-21++G*"].push_back("sulfur");
  BasisList["3-21++G*"].push_back("chlorine");
  BasisList["3-21++G*"].push_back("argon");
  BasisList["4-31G"].push_back("hydrogen");
  BasisList["4-31G"].push_back("helium");
  BasisList["4-31G"].push_back("lithium");
  BasisList["4-31G"].push_back("beryllium");
  BasisList["4-31G"].push_back("boron");
  BasisList["4-31G"].push_back("carbon");
  BasisList["4-31G"].push_back("nitrogen");
  BasisList["4-31G"].push_back("oxygen");
  BasisList["4-31G"].push_back("fluorine");
  BasisList["4-31G"].push_back("neon");
  BasisList["4-31G"].push_back("phosphorus");
  BasisList["4-31G"].push_back("sulfur");
  BasisList["4-31G"].push_back("chlorine");
  BasisList["6-311G"].push_back("hydrogen");
  BasisList["6-311G"].push_back("helium");
  BasisList["6-311G"].push_back("lithium");
  BasisList["6-311G"].push_back("beryllium");
  BasisList["6-311G"].push_back("boron");
  BasisList["6-311G"].push_back("carbon");
  BasisList["6-311G"].push_back("nitrogen");
  BasisList["6-311G"].push_back("oxygen");
  BasisList["6-311G"].push_back("fluorine");
  BasisList["6-311G"].push_back("neon");
  BasisList["6-311G"].push_back("sodium");
  BasisList["6-311G"].push_back("magnesium");
  BasisList["6-311G"].push_back("aluminum");
  BasisList["6-311G"].push_back("silicon");
  BasisList["6-311G"].push_back("phosphorus");
  BasisList["6-311G"].push_back("sulfur");
  BasisList["6-311G"].push_back("chlorine");
  BasisList["6-311G"].push_back("argon");
  BasisList["6-311G"].push_back("potassium");
  BasisList["6-311G"].push_back("calcium");
  BasisList["6-311G"].push_back("gallium");
  BasisList["6-311G"].push_back("germanium");
  BasisList["6-311G"].push_back("arsenic");
  BasisList["6-311G"].push_back("selenium");
  BasisList["6-311G"].push_back("bromine");
  BasisList["6-311G"].push_back("krypton");
  BasisList["6-311G(2df,2pd)"].push_back("hydrogen");
  BasisList["6-311G(2df,2pd)"].push_back("helium");
  BasisList["6-311G(2df,2pd)"].push_back("lithium");
  BasisList["6-311G(2df,2pd)"].push_back("beryllium");
  BasisList["6-311G(2df,2pd)"].push_back("boron");
  BasisList["6-311G(2df,2pd)"].push_back("carbon");
  BasisList["6-311G(2df,2pd)"].push_back("nitrogen");
  BasisList["6-311G(2df,2pd)"].push_back("oxygen");
  BasisList["6-311G(2df,2pd)"].push_back("fluorine");
  BasisList["6-311G(2df,2pd)"].push_back("neon");
  BasisList["6-311G(2df,2pd)"].push_back("potassium");
  BasisList["6-311G(2df,2pd)"].push_back("calcium");
  BasisList["6-311G*"].push_back("hydrogen");
  BasisList["6-311G*"].push_back("helium");
  BasisList["6-311G*"].push_back("lithium");
  BasisList["6-311G*"].push_back("beryllium");
  BasisList["6-311G*"].push_back("boron");
  BasisList["6-311G*"].push_back("carbon");
  BasisList["6-311G*"].push_back("nitrogen");
  BasisList["6-311G*"].push_back("oxygen");
  BasisList["6-311G*"].push_back("fluorine");
  BasisList["6-311G*"].push_back("neon");
  BasisList["6-311G*"].push_back("sodium");
  BasisList["6-311G*"].push_back("magnesium");
  BasisList["6-311G*"].push_back("aluminum");
  BasisList["6-311G*"].push_back("silicon");
  BasisList["6-311G*"].push_back("phosphorus");
  BasisList["6-311G*"].push_back("sulfur");
  BasisList["6-311G*"].push_back("chlorine");
  BasisList["6-311G*"].push_back("argon");
  BasisList["6-311G*"].push_back("potassium");
  BasisList["6-311G*"].push_back("calcium");
  BasisList["6-311G*"].push_back("gallium");
  BasisList["6-311G*"].push_back("germanium");
  BasisList["6-311G*"].push_back("arsenic");
  BasisList["6-311G*"].push_back("selenium");
  BasisList["6-311G*"].push_back("bromine");
  BasisList["6-311G*"].push_back("krypton");
  BasisList["6-311G**"].push_back("hydrogen");
  BasisList["6-311G**"].push_back("helium");
  BasisList["6-311G**"].push_back("lithium");
  BasisList["6-311G**"].push_back("beryllium");
  BasisList["6-311G**"].push_back("boron");
  BasisList["6-311G**"].push_back("carbon");
  BasisList["6-311G**"].push_back("nitrogen");
  BasisList["6-311G**"].push_back("oxygen");
  BasisList["6-311G**"].push_back("fluorine");
  BasisList["6-311G**"].push_back("neon");
  BasisList["6-311G**"].push_back("sodium");
  BasisList["6-311G**"].push_back("magnesium");
  BasisList["6-311G**"].push_back("aluminum");
  BasisList["6-311G**"].push_back("silicon");
  BasisList["6-311G**"].push_back("phosphorus");
  BasisList["6-311G**"].push_back("sulfur");
  BasisList["6-311G**"].push_back("chlorine");
  BasisList["6-311G**"].push_back("argon");
  BasisList["6-311G**"].push_back("potassium");
  BasisList["6-311G**"].push_back("calcium");
  BasisList["6-311G**"].push_back("gallium");
  BasisList["6-311G**"].push_back("germanium");
  BasisList["6-311G**"].push_back("arsenic");
  BasisList["6-311G**"].push_back("selenium");
  BasisList["6-311G**"].push_back("bromine");
  BasisList["6-311G**"].push_back("krypton");
  BasisList["6-311++G(2d,2p)"].push_back("hydrogen");
  BasisList["6-311++G(2d,2p)"].push_back("helium");
  BasisList["6-311++G(2d,2p)"].push_back("lithium");
  BasisList["6-311++G(2d,2p)"].push_back("beryllium");
  BasisList["6-311++G(2d,2p)"].push_back("boron");
  BasisList["6-311++G(2d,2p)"].push_back("carbon");
  BasisList["6-311++G(2d,2p)"].push_back("nitrogen");
  BasisList["6-311++G(2d,2p)"].push_back("oxygen");
  BasisList["6-311++G(2d,2p)"].push_back("fluorine");
  BasisList["6-311++G(2d,2p)"].push_back("neon");
  BasisList["6-311++G(2d,2p)"].push_back("sodium");
  BasisList["6-311++G(2d,2p)"].push_back("magnesium");
  BasisList["6-311++G(2d,2p)"].push_back("aluminum");
  BasisList["6-311++G(2d,2p)"].push_back("silicon");
  BasisList["6-311++G(2d,2p)"].push_back("phosphorus");
  BasisList["6-311++G(2d,2p)"].push_back("sulfur");
  BasisList["6-311++G(2d,2p)"].push_back("chlorine");
  BasisList["6-311++G(2d,2p)"].push_back("argon");
  BasisList["6-311++G(2d,2p)"].push_back("potassium");
  BasisList["6-311++G(2d,2p)"].push_back("calcium");
  BasisList["6-311++G(3df,3pd)"].push_back("hydrogen");
  BasisList["6-311++G(3df,3pd)"].push_back("helium");
  BasisList["6-311++G(3df,3pd)"].push_back("lithium");
  BasisList["6-311++G(3df,3pd)"].push_back("beryllium");
  BasisList["6-311++G(3df,3pd)"].push_back("boron");
  BasisList["6-311++G(3df,3pd)"].push_back("carbon");
  BasisList["6-311++G(3df,3pd)"].push_back("nitrogen");
  BasisList["6-311++G(3df,3pd)"].push_back("oxygen");
  BasisList["6-311++G(3df,3pd)"].push_back("fluorine");
  BasisList["6-311++G(3df,3pd)"].push_back("neon");
  BasisList["6-311++G(3df,3pd)"].push_back("sodium");
  BasisList["6-311++G(3df,3pd)"].push_back("magnesium");
  BasisList["6-311++G(3df,3pd)"].push_back("aluminum");
  BasisList["6-311++G(3df,3pd)"].push_back("silicon");
  BasisList["6-311++G(3df,3pd)"].push_back("phosphorus");
  BasisList["6-311++G(3df,3pd)"].push_back("sulfur");
  BasisList["6-311++G(3df,3pd)"].push_back("chlorine");
  BasisList["6-311++G(3df,3pd)"].push_back("argon");
  BasisList["6-311++G**"].push_back("hydrogen");
  BasisList["6-311++G**"].push_back("helium");
  BasisList["6-311++G**"].push_back("lithium");
  BasisList["6-311++G**"].push_back("beryllium");
  BasisList["6-311++G**"].push_back("boron");
  BasisList["6-311++G**"].push_back("carbon");
  BasisList["6-311++G**"].push_back("nitrogen");
  BasisList["6-311++G**"].push_back("oxygen");
  BasisList["6-311++G**"].push_back("fluorine");
  BasisList["6-311++G**"].push_back("neon");
  BasisList["6-31G"].push_back("hydrogen");
  BasisList["6-31G"].push_back("helium");
  BasisList["6-31G"].push_back("lithium");
  BasisList["6-31G"].push_back("beryllium");
  BasisList["6-31G"].push_back("boron");
  BasisList["6-31G"].push_back("carbon");
  BasisList["6-31G"].push_back("nitrogen");
  BasisList["6-31G"].push_back("oxygen");
  BasisList["6-31G"].push_back("fluorine");
  BasisList["6-31G"].push_back("neon");
  BasisList["6-31G"].push_back("sodium");
  BasisList["6-31G"].push_back("magnesium");
  BasisList["6-31G"].push_back("aluminum");
  BasisList["6-31G"].push_back("silicon");
  BasisList["6-31G"].push_back("phosphorus");
  BasisList["6-31G"].push_back("sulfur");
  BasisList["6-31G"].push_back("chlorine");
  BasisList["6-31G"].push_back("argon");
  BasisList["6-31G"].push_back("potassium");
  BasisList["6-31G"].push_back("calcium");
  BasisList["6-31G"].push_back("scandium");
  BasisList["6-31G"].push_back("titanium");
  BasisList["6-31G"].push_back("vanadium");
  BasisList["6-31G"].push_back("chromium");
  BasisList["6-31G"].push_back("manganese");
  BasisList["6-31G"].push_back("iron");
  BasisList["6-31G"].push_back("cobalt");
  BasisList["6-31G"].push_back("nickel");
  BasisList["6-31G"].push_back("copper");
  BasisList["6-31G"].push_back("zinc");
  BasisList["6-31G*"].push_back("hydrogen");
  BasisList["6-31G*"].push_back("helium");
  BasisList["6-31G*"].push_back("lithium");
  BasisList["6-31G*"].push_back("beryllium");
  BasisList["6-31G*"].push_back("boron");
  BasisList["6-31G*"].push_back("carbon");
  BasisList["6-31G*"].push_back("nitrogen");
  BasisList["6-31G*"].push_back("oxygen");
  BasisList["6-31G*"].push_back("fluorine");
  BasisList["6-31G*"].push_back("neon");
  BasisList["6-31G*"].push_back("sodium");
  BasisList["6-31G*"].push_back("magnesium");
  BasisList["6-31G*"].push_back("aluminum");
  BasisList["6-31G*"].push_back("silicon");
  BasisList["6-31G*"].push_back("phosphorus");
  BasisList["6-31G*"].push_back("sulfur");
  BasisList["6-31G*"].push_back("chlorine");
  BasisList["6-31G*"].push_back("argon");
  BasisList["6-31G*"].push_back("potassium");
  BasisList["6-31G*"].push_back("calcium");
  BasisList["6-31G*"].push_back("scandium");
  BasisList["6-31G*"].push_back("titanium");
  BasisList["6-31G*"].push_back("vanadium");
  BasisList["6-31G*"].push_back("chromium");
  BasisList["6-31G*"].push_back("manganese");
  BasisList["6-31G*"].push_back("iron");
  BasisList["6-31G*"].push_back("cobalt");
  BasisList["6-31G*"].push_back("nickel");
  BasisList["6-31G*"].push_back("copper");
  BasisList["6-31G*"].push_back("zinc");
  BasisList["6-31G**"].push_back("hydrogen");
  BasisList["6-31G**"].push_back("helium");
  BasisList["6-31G**"].push_back("lithium");
  BasisList["6-31G**"].push_back("beryllium");
  BasisList["6-31G**"].push_back("boron");
  BasisList["6-31G**"].push_back("carbon");
  BasisList["6-31G**"].push_back("nitrogen");
  BasisList["6-31G**"].push_back("oxygen");
  BasisList["6-31G**"].push_back("fluorine");
  BasisList["6-31G**"].push_back("neon");
  BasisList["6-31G**"].push_back("sodium");
  BasisList["6-31G**"].push_back("magnesium");
  BasisList["6-31G**"].push_back("aluminum");
  BasisList["6-31G**"].push_back("silicon");
  BasisList["6-31G**"].push_back("phosphorus");
  BasisList["6-31G**"].push_back("sulfur");
  BasisList["6-31G**"].push_back("chlorine");
  BasisList["6-31G**"].push_back("argon");
  BasisList["6-31G**"].push_back("potassium");
  BasisList["6-31G**"].push_back("calcium");
  BasisList["6-31G**"].push_back("scandium");
  BasisList["6-31G**"].push_back("titanium");
  BasisList["6-31G**"].push_back("vanadium");
  BasisList["6-31G**"].push_back("chromium");
  BasisList["6-31G**"].push_back("manganese");
  BasisList["6-31G**"].push_back("iron");
  BasisList["6-31G**"].push_back("cobalt");
  BasisList["6-31G**"].push_back("nickel");
  BasisList["6-31G**"].push_back("copper");
  BasisList["6-31G**"].push_back("zinc");
  BasisList["6-31+G*"].push_back("hydrogen");
  BasisList["6-31+G*"].push_back("helium");
  BasisList["6-31+G*"].push_back("lithium");
  BasisList["6-31+G*"].push_back("beryllium");
  BasisList["6-31+G*"].push_back("boron");
  BasisList["6-31+G*"].push_back("carbon");
  BasisList["6-31+G*"].push_back("nitrogen");
  BasisList["6-31+G*"].push_back("oxygen");
  BasisList["6-31+G*"].push_back("fluorine");
  BasisList["6-31+G*"].push_back("neon");
  BasisList["6-31+G*"].push_back("sodium");
  BasisList["6-31+G*"].push_back("magnesium");
  BasisList["6-31+G*"].push_back("aluminum");
  BasisList["6-31+G*"].push_back("silicon");
  BasisList["6-31+G*"].push_back("phosphorus");
  BasisList["6-31+G*"].push_back("sulfur");
  BasisList["6-31+G*"].push_back("chlorine");
  BasisList["6-31+G*"].push_back("argon");
  BasisList["6-31++G"].push_back("hydrogen");
  BasisList["6-31++G"].push_back("helium");
  BasisList["6-31++G"].push_back("lithium");
  BasisList["6-31++G"].push_back("beryllium");
  BasisList["6-31++G"].push_back("boron");
  BasisList["6-31++G"].push_back("carbon");
  BasisList["6-31++G"].push_back("nitrogen");
  BasisList["6-31++G"].push_back("oxygen");
  BasisList["6-31++G"].push_back("fluorine");
  BasisList["6-31++G"].push_back("neon");
  BasisList["6-31++G"].push_back("sodium");
  BasisList["6-31++G"].push_back("magnesium");
  BasisList["6-31++G"].push_back("aluminum");
  BasisList["6-31++G"].push_back("silicon");
  BasisList["6-31++G"].push_back("phosphorus");
  BasisList["6-31++G"].push_back("sulfur");
  BasisList["6-31++G"].push_back("chlorine");
  BasisList["6-31++G"].push_back("argon");
  BasisList["6-31++G"].push_back("potassium");
  BasisList["6-31++G"].push_back("calcium");
  BasisList["6-31++G*"].push_back("hydrogen");
  BasisList["6-31++G*"].push_back("helium");
  BasisList["6-31++G*"].push_back("lithium");
  BasisList["6-31++G*"].push_back("beryllium");
  BasisList["6-31++G*"].push_back("boron");
  BasisList["6-31++G*"].push_back("carbon");
  BasisList["6-31++G*"].push_back("nitrogen");
  BasisList["6-31++G*"].push_back("oxygen");
  BasisList["6-31++G*"].push_back("fluorine");
  BasisList["6-31++G*"].push_back("neon");
  BasisList["6-31++G*"].push_back("sodium");
  BasisList["6-31++G*"].push_back("magnesium");
  BasisList["6-31++G*"].push_back("aluminum");
  BasisList["6-31++G*"].push_back("silicon");
  BasisList["6-31++G*"].push_back("phosphorus");
  BasisList["6-31++G*"].push_back("sulfur");
  BasisList["6-31++G*"].push_back("chlorine");
  BasisList["6-31++G*"].push_back("argon");
  BasisList["6-31++G**"].push_back("hydrogen");
  BasisList["6-31++G**"].push_back("helium");
  BasisList["6-31++G**"].push_back("lithium");
  BasisList["6-31++G**"].push_back("beryllium");
  BasisList["6-31++G**"].push_back("boron");
  BasisList["6-31++G**"].push_back("carbon");
  BasisList["6-31++G**"].push_back("nitrogen");
  BasisList["6-31++G**"].push_back("oxygen");
  BasisList["6-31++G**"].push_back("fluorine");
  BasisList["6-31++G**"].push_back("neon");
  BasisList["6-31++G**"].push_back("sodium");
  BasisList["6-31++G**"].push_back("magnesium");
  BasisList["6-31++G**"].push_back("aluminum");
  BasisList["6-31++G**"].push_back("silicon");
  BasisList["6-31++G**"].push_back("phosphorus");
  BasisList["6-31++G**"].push_back("sulfur");
  BasisList["6-31++G**"].push_back("chlorine");
  BasisList["6-31++G**"].push_back("argon");
  BasisList["aug-cc-pCV5Z"].push_back("boron");
  BasisList["aug-cc-pCV5Z"].push_back("carbon");
  BasisList["aug-cc-pCV5Z"].push_back("nitrogen");
  BasisList["aug-cc-pCV5Z"].push_back("oxygen");
  BasisList["aug-cc-pCV5Z"].push_back("fluorine");
  BasisList["aug-cc-pCV5Z"].push_back("neon");
  BasisList["aug-cc-pCVDZ"].push_back("boron");
  BasisList["aug-cc-pCVDZ"].push_back("carbon");
  BasisList["aug-cc-pCVDZ"].push_back("nitrogen");
  BasisList["aug-cc-pCVDZ"].push_back("oxygen");
  BasisList["aug-cc-pCVDZ"].push_back("fluorine");
  BasisList["aug-cc-pCVDZ"].push_back("neon");
  BasisList["aug-cc-pCVDZ"].push_back("aluminum");
  BasisList["aug-cc-pCVDZ"].push_back("silicon");
  BasisList["aug-cc-pCVDZ"].push_back("phosphorus");
  BasisList["aug-cc-pCVDZ"].push_back("sulfur");
  BasisList["aug-cc-pCVDZ"].push_back("chlorine");
  BasisList["aug-cc-pCVDZ"].push_back("argon");
  BasisList["aug-cc-pCVQZ"].push_back("boron");
  BasisList["aug-cc-pCVQZ"].push_back("carbon");
  BasisList["aug-cc-pCVQZ"].push_back("nitrogen");
  BasisList["aug-cc-pCVQZ"].push_back("oxygen");
  BasisList["aug-cc-pCVQZ"].push_back("fluorine");
  BasisList["aug-cc-pCVQZ"].push_back("neon");
  BasisList["aug-cc-pCVQZ"].push_back("aluminum");
  BasisList["aug-cc-pCVQZ"].push_back("silicon");
  BasisList["aug-cc-pCVQZ"].push_back("phosphorus");
  BasisList["aug-cc-pCVQZ"].push_back("sulfur");
  BasisList["aug-cc-pCVQZ"].push_back("chlorine");
  BasisList["aug-cc-pCVQZ"].push_back("argon");
  BasisList["aug-cc-pCVTZ"].push_back("boron");
  BasisList["aug-cc-pCVTZ"].push_back("carbon");
  BasisList["aug-cc-pCVTZ"].push_back("nitrogen");
  BasisList["aug-cc-pCVTZ"].push_back("oxygen");
  BasisList["aug-cc-pCVTZ"].push_back("fluorine");
  BasisList["aug-cc-pCVTZ"].push_back("neon");
  BasisList["aug-cc-pCVTZ"].push_back("aluminum");
  BasisList["aug-cc-pCVTZ"].push_back("silicon");
  BasisList["aug-cc-pCVTZ"].push_back("phosphorus");
  BasisList["aug-cc-pCVTZ"].push_back("sulfur");
  BasisList["aug-cc-pCVTZ"].push_back("chlorine");
  BasisList["aug-cc-pCVTZ"].push_back("argon");
  BasisList["aug-cc-pV5Z"].push_back("hydrogen");
  BasisList["aug-cc-pV5Z"].push_back("helium");
  BasisList["aug-cc-pV5Z"].push_back("boron");
  BasisList["aug-cc-pV5Z"].push_back("carbon");
  BasisList["aug-cc-pV5Z"].push_back("nitrogen");
  BasisList["aug-cc-pV5Z"].push_back("oxygen");
  BasisList["aug-cc-pV5Z"].push_back("fluorine");
  BasisList["aug-cc-pV5Z"].push_back("neon");
  BasisList["aug-cc-pV5Z"].push_back("aluminum");
  BasisList["aug-cc-pV5Z"].push_back("silicon");
  BasisList["aug-cc-pV5Z"].push_back("phosphorus");
  BasisList["aug-cc-pV5Z"].push_back("sulfur");
  BasisList["aug-cc-pV5Z"].push_back("chlorine");
  BasisList["aug-cc-pV5Z"].push_back("argon");
  BasisList["aug-cc-pV5Z"].push_back("gallium");
  BasisList["aug-cc-pV5Z"].push_back("germanium");
  BasisList["aug-cc-pV5Z"].push_back("arsenic");
  BasisList["aug-cc-pV5Z"].push_back("selenium");
  BasisList["aug-cc-pV5Z"].push_back("bromine");
  BasisList["aug-cc-pV5Z"].push_back("krypton");
  BasisList["aug-cc-pV6Z"].push_back("hydrogen");
  BasisList["aug-cc-pV6Z"].push_back("helium");
  BasisList["aug-cc-pV6Z"].push_back("boron");
  BasisList["aug-cc-pV6Z"].push_back("carbon");
  BasisList["aug-cc-pV6Z"].push_back("nitrogen");
  BasisList["aug-cc-pV6Z"].push_back("oxygen");
  BasisList["aug-cc-pV6Z"].push_back("fluorine");
  BasisList["aug-cc-pV6Z"].push_back("neon");
  BasisList["aug-cc-pV6Z"].push_back("aluminum");
  BasisList["aug-cc-pV6Z"].push_back("silicon");
  BasisList["aug-cc-pV6Z"].push_back("phosphorus");
  BasisList["aug-cc-pV6Z"].push_back("sulfur");
  BasisList["aug-cc-pV6Z"].push_back("chlorine");
  BasisList["aug-cc-pV6Z"].push_back("argon");
  BasisList["aug-cc-pVDZ"].push_back("hydrogen");
  BasisList["aug-cc-pVDZ"].push_back("helium");
  BasisList["aug-cc-pVDZ"].push_back("boron");
  BasisList["aug-cc-pVDZ"].push_back("carbon");
  BasisList["aug-cc-pVDZ"].push_back("nitrogen");
  BasisList["aug-cc-pVDZ"].push_back("oxygen");
  BasisList["aug-cc-pVDZ"].push_back("fluorine");
  BasisList["aug-cc-pVDZ"].push_back("neon");
  BasisList["aug-cc-pVDZ"].push_back("aluminum");
  BasisList["aug-cc-pVDZ"].push_back("silicon");
  BasisList["aug-cc-pVDZ"].push_back("phosphorus");
  BasisList["aug-cc-pVDZ"].push_back("sulfur");
  BasisList["aug-cc-pVDZ"].push_back("chlorine");
  BasisList["aug-cc-pVDZ"].push_back("argon");
  BasisList["aug-cc-pVDZ"].push_back("gallium");
  BasisList["aug-cc-pVDZ"].push_back("germanium");
  BasisList["aug-cc-pVDZ"].push_back("arsenic");
  BasisList["aug-cc-pVDZ"].push_back("selenium");
  BasisList["aug-cc-pVDZ"].push_back("bromine");
  BasisList["aug-cc-pVDZ"].push_back("krypton");
  BasisList["aug-cc-pVQZ"].push_back("hydrogen");
  BasisList["aug-cc-pVQZ"].push_back("helium");
  BasisList["aug-cc-pVQZ"].push_back("boron");
  BasisList["aug-cc-pVQZ"].push_back("carbon");
  BasisList["aug-cc-pVQZ"].push_back("nitrogen");
  BasisList["aug-cc-pVQZ"].push_back("oxygen");
  BasisList["aug-cc-pVQZ"].push_back("fluorine");
  BasisList["aug-cc-pVQZ"].push_back("neon");
  BasisList["aug-cc-pVQZ"].push_back("aluminum");
  BasisList["aug-cc-pVQZ"].push_back("silicon");
  BasisList["aug-cc-pVQZ"].push_back("phosphorus");
  BasisList["aug-cc-pVQZ"].push_back("sulfur");
  BasisList["aug-cc-pVQZ"].push_back("chlorine");
  BasisList["aug-cc-pVQZ"].push_back("argon");
  BasisList["aug-cc-pVQZ"].push_back("gallium");
  BasisList["aug-cc-pVQZ"].push_back("germanium");
  BasisList["aug-cc-pVQZ"].push_back("arsenic");
  BasisList["aug-cc-pVQZ"].push_back("selenium");
  BasisList["aug-cc-pVQZ"].push_back("bromine");
  BasisList["aug-cc-pVQZ"].push_back("krypton");
  BasisList["aug-cc-pVTZ"].push_back("hydrogen");
  BasisList["aug-cc-pVTZ"].push_back("helium");
  BasisList["aug-cc-pVTZ"].push_back("boron");
  BasisList["aug-cc-pVTZ"].push_back("carbon");
  BasisList["aug-cc-pVTZ"].push_back("nitrogen");
  BasisList["aug-cc-pVTZ"].push_back("oxygen");
  BasisList["aug-cc-pVTZ"].push_back("fluorine");
  BasisList["aug-cc-pVTZ"].push_back("neon");
  BasisList["aug-cc-pVTZ"].push_back("aluminum");
  BasisList["aug-cc-pVTZ"].push_back("silicon");
  BasisList["aug-cc-pVTZ"].push_back("phosphorus");
  BasisList["aug-cc-pVTZ"].push_back("sulfur");
  BasisList["aug-cc-pVTZ"].push_back("chlorine");
  BasisList["aug-cc-pVTZ"].push_back("argon");
  BasisList["aug-cc-pVTZ"].push_back("gallium");
  BasisList["aug-cc-pVTZ"].push_back("germanium");
  BasisList["aug-cc-pVTZ"].push_back("arsenic");
  BasisList["aug-cc-pVTZ"].push_back("selenium");
  BasisList["aug-cc-pVTZ"].push_back("bromine");
  BasisList["aug-cc-pVTZ"].push_back("krypton");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("scandium");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("titanium");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("vanadium");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("chromium");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("manganese");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("iron");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("cobalt");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("nickel");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("copper");
  BasisList["augmentation-cc-pV5Z-DK"].push_back("zinc");
  BasisList["augmentation-cc-pV5Z"].push_back("hydrogen");
  BasisList["augmentation-cc-pV5Z"].push_back("boron");
  BasisList["augmentation-cc-pV5Z"].push_back("carbon");
  BasisList["augmentation-cc-pV5Z"].push_back("nitrogen");
  BasisList["augmentation-cc-pV5Z"].push_back("oxygen");
  BasisList["augmentation-cc-pV5Z"].push_back("fluorine");
  BasisList["augmentation-cc-pV5Z"].push_back("neon");
  BasisList["augmentation-cc-pV5Z"].push_back("aluminum");
  BasisList["augmentation-cc-pV5Z"].push_back("silicon");
  BasisList["augmentation-cc-pV5Z"].push_back("phosphorus");
  BasisList["augmentation-cc-pV5Z"].push_back("sulfur");
  BasisList["augmentation-cc-pV5Z"].push_back("chlorine");
  BasisList["augmentation-cc-pV5Z"].push_back("argon");
  BasisList["augmentation-cc-pV5Z"].push_back("gallium");
  BasisList["augmentation-cc-pV5Z"].push_back("germanium");
  BasisList["augmentation-cc-pV5Z"].push_back("arsenic");
  BasisList["augmentation-cc-pV5Z"].push_back("selenium");
  BasisList["augmentation-cc-pV5Z"].push_back("bromine");
  BasisList["augmentation-cc-pV5Z"].push_back("krypton");
  BasisList["augmentation-cc-pV5Z"].push_back("scandium");
  BasisList["augmentation-cc-pV5Z"].push_back("titanium");
  BasisList["augmentation-cc-pV5Z"].push_back("vanadium");
  BasisList["augmentation-cc-pV5Z"].push_back("chromium");
  BasisList["augmentation-cc-pV5Z"].push_back("manganese");
  BasisList["augmentation-cc-pV5Z"].push_back("iron");
  BasisList["augmentation-cc-pV5Z"].push_back("cobalt");
  BasisList["augmentation-cc-pV5Z"].push_back("nickel");
  BasisList["augmentation-cc-pV5Z"].push_back("copper");
  BasisList["augmentation-cc-pV5Z"].push_back("zinc");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("hydrogen");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("helium");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("boron");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("carbon");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("nitrogen");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("oxygen");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("fluorine");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("neon");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("aluminum");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("silicon");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("phosphorus");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("sulfur");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("chlorine");
  BasisList["augmentation-cc-pV5Z-RI"].push_back("argon");
  BasisList["augmentation-cc-pV6Z"].push_back("hydrogen");
  BasisList["augmentation-cc-pV6Z"].push_back("helium");
  BasisList["augmentation-cc-pV6Z"].push_back("boron");
  BasisList["augmentation-cc-pV6Z"].push_back("carbon");
  BasisList["augmentation-cc-pV6Z"].push_back("nitrogen");
  BasisList["augmentation-cc-pV6Z"].push_back("oxygen");
  BasisList["augmentation-cc-pV6Z"].push_back("fluorine");
  BasisList["augmentation-cc-pV6Z"].push_back("neon");
  BasisList["augmentation-cc-pV6Z"].push_back("aluminum");
  BasisList["augmentation-cc-pV6Z"].push_back("silicon");
  BasisList["augmentation-cc-pV6Z"].push_back("phosphorus");
  BasisList["augmentation-cc-pV6Z"].push_back("sulfur");
  BasisList["augmentation-cc-pV6Z"].push_back("chlorine");
  BasisList["augmentation-cc-pV6Z"].push_back("argon");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("hydrogen");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("helium");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("boron");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("carbon");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("nitrogen");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("oxygen");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("fluorine");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("neon");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("aluminum");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("silicon");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("phosphorus");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("sulfur");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("chlorine");
  BasisList["augmentation-cc-pV6Z-RI"].push_back("argon");
  BasisList["augmentation-cc-pVDZ"].push_back("hydrogen");
  BasisList["augmentation-cc-pVDZ"].push_back("boron");
  BasisList["augmentation-cc-pVDZ"].push_back("carbon");
  BasisList["augmentation-cc-pVDZ"].push_back("nitrogen");
  BasisList["augmentation-cc-pVDZ"].push_back("oxygen");
  BasisList["augmentation-cc-pVDZ"].push_back("fluorine");
  BasisList["augmentation-cc-pVDZ"].push_back("neon");
  BasisList["augmentation-cc-pVDZ"].push_back("aluminum");
  BasisList["augmentation-cc-pVDZ"].push_back("silicon");
  BasisList["augmentation-cc-pVDZ"].push_back("phosphorus");
  BasisList["augmentation-cc-pVDZ"].push_back("sulfur");
  BasisList["augmentation-cc-pVDZ"].push_back("chlorine");
  BasisList["augmentation-cc-pVDZ"].push_back("argon");
  BasisList["augmentation-cc-pVDZ"].push_back("gallium");
  BasisList["augmentation-cc-pVDZ"].push_back("germanium");
  BasisList["augmentation-cc-pVDZ"].push_back("arsenic");
  BasisList["augmentation-cc-pVDZ"].push_back("selenium");
  BasisList["augmentation-cc-pVDZ"].push_back("bromine");
  BasisList["augmentation-cc-pVDZ"].push_back("krypton");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("hydrogen");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("helium");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("boron");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("carbon");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("nitrogen");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("oxygen");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("fluorine");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("neon");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("aluminum");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("silicon");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("phosphorus");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("sulfur");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("chlorine");
  BasisList["augmentation-cc-pVDZ-RI"].push_back("argon");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("scandium");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("titanium");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("vanadium");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("chromium");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("manganese");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("iron");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("cobalt");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("nickel");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("copper");
  BasisList["augmentation-cc-pVQZ-DK"].push_back("zinc");
  BasisList["augmentation-cc-pVQZ"].push_back("hydrogen");
  BasisList["augmentation-cc-pVQZ"].push_back("boron");
  BasisList["augmentation-cc-pVQZ"].push_back("carbon");
  BasisList["augmentation-cc-pVQZ"].push_back("nitrogen");
  BasisList["augmentation-cc-pVQZ"].push_back("oxygen");
  BasisList["augmentation-cc-pVQZ"].push_back("fluorine");
  BasisList["augmentation-cc-pVQZ"].push_back("neon");
  BasisList["augmentation-cc-pVQZ"].push_back("aluminum");
  BasisList["augmentation-cc-pVQZ"].push_back("silicon");
  BasisList["augmentation-cc-pVQZ"].push_back("phosphorus");
  BasisList["augmentation-cc-pVQZ"].push_back("sulfur");
  BasisList["augmentation-cc-pVQZ"].push_back("chlorine");
  BasisList["augmentation-cc-pVQZ"].push_back("argon");
  BasisList["augmentation-cc-pVQZ"].push_back("gallium");
  BasisList["augmentation-cc-pVQZ"].push_back("germanium");
  BasisList["augmentation-cc-pVQZ"].push_back("arsenic");
  BasisList["augmentation-cc-pVQZ"].push_back("selenium");
  BasisList["augmentation-cc-pVQZ"].push_back("bromine");
  BasisList["augmentation-cc-pVQZ"].push_back("krypton");
  BasisList["augmentation-cc-pVQZ"].push_back("scandium");
  BasisList["augmentation-cc-pVQZ"].push_back("titanium");
  BasisList["augmentation-cc-pVQZ"].push_back("vanadium");
  BasisList["augmentation-cc-pVQZ"].push_back("chromium");
  BasisList["augmentation-cc-pVQZ"].push_back("manganese");
  BasisList["augmentation-cc-pVQZ"].push_back("iron");
  BasisList["augmentation-cc-pVQZ"].push_back("cobalt");
  BasisList["augmentation-cc-pVQZ"].push_back("nickel");
  BasisList["augmentation-cc-pVQZ"].push_back("copper");
  BasisList["augmentation-cc-pVQZ"].push_back("zinc");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("hydrogen");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("helium");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("boron");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("carbon");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("nitrogen");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("oxygen");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("fluorine");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("neon");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("aluminum");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("silicon");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("phosphorus");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("sulfur");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("chlorine");
  BasisList["augmentation-cc-pVQZ-RI"].push_back("argon");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("scandium");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("titanium");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("vanadium");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("chromium");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("manganese");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("iron");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("cobalt");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("nickel");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("copper");
  BasisList["augmentation-cc-pVTZ-DK"].push_back("zinc");
  BasisList["augmentation-cc-pVTZ"].push_back("hydrogen");
  BasisList["augmentation-cc-pVTZ"].push_back("boron");
  BasisList["augmentation-cc-pVTZ"].push_back("carbon");
  BasisList["augmentation-cc-pVTZ"].push_back("nitrogen");
  BasisList["augmentation-cc-pVTZ"].push_back("oxygen");
  BasisList["augmentation-cc-pVTZ"].push_back("fluorine");
  BasisList["augmentation-cc-pVTZ"].push_back("neon");
  BasisList["augmentation-cc-pVTZ"].push_back("aluminum");
  BasisList["augmentation-cc-pVTZ"].push_back("silicon");
  BasisList["augmentation-cc-pVTZ"].push_back("phosphorus");
  BasisList["augmentation-cc-pVTZ"].push_back("sulfur");
  BasisList["augmentation-cc-pVTZ"].push_back("chlorine");
  BasisList["augmentation-cc-pVTZ"].push_back("argon");
  BasisList["augmentation-cc-pVTZ"].push_back("gallium");
  BasisList["augmentation-cc-pVTZ"].push_back("germanium");
  BasisList["augmentation-cc-pVTZ"].push_back("arsenic");
  BasisList["augmentation-cc-pVTZ"].push_back("selenium");
  BasisList["augmentation-cc-pVTZ"].push_back("bromine");
  BasisList["augmentation-cc-pVTZ"].push_back("krypton");
  BasisList["augmentation-cc-pVTZ"].push_back("scandium");
  BasisList["augmentation-cc-pVTZ"].push_back("titanium");
  BasisList["augmentation-cc-pVTZ"].push_back("vanadium");
  BasisList["augmentation-cc-pVTZ"].push_back("chromium");
  BasisList["augmentation-cc-pVTZ"].push_back("manganese");
  BasisList["augmentation-cc-pVTZ"].push_back("iron");
  BasisList["augmentation-cc-pVTZ"].push_back("cobalt");
  BasisList["augmentation-cc-pVTZ"].push_back("nickel");
  BasisList["augmentation-cc-pVTZ"].push_back("copper");
  BasisList["augmentation-cc-pVTZ"].push_back("zinc");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("hydrogen");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("helium");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("boron");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("carbon");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("nitrogen");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("oxygen");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("fluorine");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("neon");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("aluminum");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("silicon");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("phosphorus");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("sulfur");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("chlorine");
  BasisList["augmentation-cc-pVTZ-RI"].push_back("argon");
  BasisList["cc-pCV5Z"].push_back("boron");
  BasisList["cc-pCV5Z"].push_back("carbon");
  BasisList["cc-pCV5Z"].push_back("nitrogen");
  BasisList["cc-pCV5Z"].push_back("oxygen");
  BasisList["cc-pCV5Z"].push_back("fluorine");
  BasisList["cc-pCV5Z"].push_back("neon");
  BasisList["cc-pCVDZ"].push_back("lithium");
  BasisList["cc-pCVDZ"].push_back("boron");
  BasisList["cc-pCVDZ"].push_back("carbon");
  BasisList["cc-pCVDZ"].push_back("nitrogen");
  BasisList["cc-pCVDZ"].push_back("oxygen");
  BasisList["cc-pCVDZ"].push_back("fluorine");
  BasisList["cc-pCVDZ"].push_back("neon");
  BasisList["cc-pCVDZ"].push_back("sodium");
  BasisList["cc-pCVDZ"].push_back("magnesium");
  BasisList["cc-pCVDZ"].push_back("aluminum");
  BasisList["cc-pCVDZ"].push_back("silicon");
  BasisList["cc-pCVDZ"].push_back("phosphorus");
  BasisList["cc-pCVDZ"].push_back("sulfur");
  BasisList["cc-pCVDZ"].push_back("chlorine");
  BasisList["cc-pCVDZ"].push_back("argon");
  BasisList["cc-pCVQZ"].push_back("lithium");
  BasisList["cc-pCVQZ"].push_back("boron");
  BasisList["cc-pCVQZ"].push_back("carbon");
  BasisList["cc-pCVQZ"].push_back("nitrogen");
  BasisList["cc-pCVQZ"].push_back("oxygen");
  BasisList["cc-pCVQZ"].push_back("fluorine");
  BasisList["cc-pCVQZ"].push_back("neon");
  BasisList["cc-pCVQZ"].push_back("sodium");
  BasisList["cc-pCVQZ"].push_back("magnesium");
  BasisList["cc-pCVQZ"].push_back("aluminum");
  BasisList["cc-pCVQZ"].push_back("silicon");
  BasisList["cc-pCVQZ"].push_back("phosphorus");
  BasisList["cc-pCVQZ"].push_back("sulfur");
  BasisList["cc-pCVQZ"].push_back("chlorine");
  BasisList["cc-pCVQZ"].push_back("argon");
  BasisList["cc-pCVTZ"].push_back("lithium");
  BasisList["cc-pCVTZ"].push_back("boron");
  BasisList["cc-pCVTZ"].push_back("carbon");
  BasisList["cc-pCVTZ"].push_back("nitrogen");
  BasisList["cc-pCVTZ"].push_back("oxygen");
  BasisList["cc-pCVTZ"].push_back("fluorine");
  BasisList["cc-pCVTZ"].push_back("neon");
  BasisList["cc-pCVTZ"].push_back("sodium");
  BasisList["cc-pCVTZ"].push_back("magnesium");
  BasisList["cc-pCVTZ"].push_back("aluminum");
  BasisList["cc-pCVTZ"].push_back("silicon");
  BasisList["cc-pCVTZ"].push_back("phosphorus");
  BasisList["cc-pCVTZ"].push_back("sulfur");
  BasisList["cc-pCVTZ"].push_back("chlorine");
  BasisList["cc-pCVTZ"].push_back("argon");
  BasisList["cc-pV5Z-DK"].push_back("hydrogen");
  BasisList["cc-pV5Z-DK"].push_back("helium");
  BasisList["cc-pV5Z-DK"].push_back("lithium");
  BasisList["cc-pV5Z-DK"].push_back("beryllium");
  BasisList["cc-pV5Z-DK"].push_back("boron");
  BasisList["cc-pV5Z-DK"].push_back("carbon");
  BasisList["cc-pV5Z-DK"].push_back("nitrogen");
  BasisList["cc-pV5Z-DK"].push_back("oxygen");
  BasisList["cc-pV5Z-DK"].push_back("fluorine");
  BasisList["cc-pV5Z-DK"].push_back("neon");
  BasisList["cc-pV5Z-DK"].push_back("aluminum");
  BasisList["cc-pV5Z-DK"].push_back("silicon");
  BasisList["cc-pV5Z-DK"].push_back("phosphorus");
  BasisList["cc-pV5Z-DK"].push_back("sulfur");
  BasisList["cc-pV5Z-DK"].push_back("chlorine");
  BasisList["cc-pV5Z-DK"].push_back("argon");
  BasisList["cc-pV5Z-DK"].push_back("gallium");
  BasisList["cc-pV5Z-DK"].push_back("germanium");
  BasisList["cc-pV5Z-DK"].push_back("arsenic");
  BasisList["cc-pV5Z-DK"].push_back("selenium");
  BasisList["cc-pV5Z-DK"].push_back("bromine");
  BasisList["cc-pV5Z-DK"].push_back("krypton");
  BasisList["cc-pV5Z-DK"].push_back("scandium");
  BasisList["cc-pV5Z-DK"].push_back("titanium");
  BasisList["cc-pV5Z-DK"].push_back("vanadium");
  BasisList["cc-pV5Z-DK"].push_back("chromium");
  BasisList["cc-pV5Z-DK"].push_back("manganese");
  BasisList["cc-pV5Z-DK"].push_back("iron");
  BasisList["cc-pV5Z-DK"].push_back("cobalt");
  BasisList["cc-pV5Z-DK"].push_back("nickel");
  BasisList["cc-pV5Z-DK"].push_back("copper");
  BasisList["cc-pV5Z-DK"].push_back("zinc");
  BasisList["cc-pV5Z"].push_back("hydrogen");
  BasisList["cc-pV5Z"].push_back("helium");
  BasisList["cc-pV5Z"].push_back("lithium");
  BasisList["cc-pV5Z"].push_back("beryllium");
  BasisList["cc-pV5Z"].push_back("boron");
  BasisList["cc-pV5Z"].push_back("carbon");
  BasisList["cc-pV5Z"].push_back("nitrogen");
  BasisList["cc-pV5Z"].push_back("oxygen");
  BasisList["cc-pV5Z"].push_back("fluorine");
  BasisList["cc-pV5Z"].push_back("neon");
  BasisList["cc-pV5Z"].push_back("sodium");
  BasisList["cc-pV5Z"].push_back("magnesium");
  BasisList["cc-pV5Z"].push_back("aluminum");
  BasisList["cc-pV5Z"].push_back("silicon");
  BasisList["cc-pV5Z"].push_back("phosphorus");
  BasisList["cc-pV5Z"].push_back("sulfur");
  BasisList["cc-pV5Z"].push_back("chlorine");
  BasisList["cc-pV5Z"].push_back("argon");
  BasisList["cc-pV5Z"].push_back("calcium");
  BasisList["cc-pV5Z"].push_back("gallium");
  BasisList["cc-pV5Z"].push_back("germanium");
  BasisList["cc-pV5Z"].push_back("arsenic");
  BasisList["cc-pV5Z"].push_back("selenium");
  BasisList["cc-pV5Z"].push_back("bromine");
  BasisList["cc-pV5Z"].push_back("krypton");
  BasisList["cc-pV5Z"].push_back("scandium");
  BasisList["cc-pV5Z"].push_back("titanium");
  BasisList["cc-pV5Z"].push_back("vanadium");
  BasisList["cc-pV5Z"].push_back("chromium");
  BasisList["cc-pV5Z"].push_back("manganese");
  BasisList["cc-pV5Z"].push_back("iron");
  BasisList["cc-pV5Z"].push_back("cobalt");
  BasisList["cc-pV5Z"].push_back("nickel");
  BasisList["cc-pV5Z"].push_back("copper");
  BasisList["cc-pV5Z"].push_back("zinc");
  BasisList["cc-pV5Z-RI"].push_back("hydrogen");
  BasisList["cc-pV5Z-RI"].push_back("helium");
  BasisList["cc-pV5Z-RI"].push_back("lithium");
  BasisList["cc-pV5Z-RI"].push_back("beryllium");
  BasisList["cc-pV5Z-RI"].push_back("boron");
  BasisList["cc-pV5Z-RI"].push_back("carbon");
  BasisList["cc-pV5Z-RI"].push_back("nitrogen");
  BasisList["cc-pV5Z-RI"].push_back("oxygen");
  BasisList["cc-pV5Z-RI"].push_back("fluorine");
  BasisList["cc-pV5Z-RI"].push_back("neon");
  BasisList["cc-pV5Z-RI"].push_back("sodium");
  BasisList["cc-pV5Z-RI"].push_back("magnesium");
  BasisList["cc-pV5Z-RI"].push_back("aluminum");
  BasisList["cc-pV5Z-RI"].push_back("silicon");
  BasisList["cc-pV5Z-RI"].push_back("phosphorus");
  BasisList["cc-pV5Z-RI"].push_back("sulfur");
  BasisList["cc-pV5Z-RI"].push_back("chlorine");
  BasisList["cc-pV5Z-RI"].push_back("argon");
  BasisList["cc-pV6Z"].push_back("hydrogen");
  BasisList["cc-pV6Z"].push_back("helium");
  BasisList["cc-pV6Z"].push_back("boron");
  BasisList["cc-pV6Z"].push_back("carbon");
  BasisList["cc-pV6Z"].push_back("nitrogen");
  BasisList["cc-pV6Z"].push_back("oxygen");
  BasisList["cc-pV6Z"].push_back("fluorine");
  BasisList["cc-pV6Z"].push_back("neon");
  BasisList["cc-pV6Z"].push_back("aluminum");
  BasisList["cc-pV6Z"].push_back("silicon");
  BasisList["cc-pV6Z"].push_back("phosphorus");
  BasisList["cc-pV6Z"].push_back("sulfur");
  BasisList["cc-pV6Z"].push_back("chlorine");
  BasisList["cc-pV6Z"].push_back("argon");
  BasisList["cc-pV6Z-RI"].push_back("hydrogen");
  BasisList["cc-pV6Z-RI"].push_back("helium");
  BasisList["cc-pV6Z-RI"].push_back("lithium");
  BasisList["cc-pV6Z-RI"].push_back("beryllium");
  BasisList["cc-pV6Z-RI"].push_back("boron");
  BasisList["cc-pV6Z-RI"].push_back("carbon");
  BasisList["cc-pV6Z-RI"].push_back("nitrogen");
  BasisList["cc-pV6Z-RI"].push_back("oxygen");
  BasisList["cc-pV6Z-RI"].push_back("fluorine");
  BasisList["cc-pV6Z-RI"].push_back("neon");
  BasisList["cc-pV6Z-RI"].push_back("sodium");
  BasisList["cc-pV6Z-RI"].push_back("magnesium");
  BasisList["cc-pV6Z-RI"].push_back("aluminum");
  BasisList["cc-pV6Z-RI"].push_back("silicon");
  BasisList["cc-pV6Z-RI"].push_back("phosphorus");
  BasisList["cc-pV6Z-RI"].push_back("sulfur");
  BasisList["cc-pV6Z-RI"].push_back("chlorine");
  BasisList["cc-pV6Z-RI"].push_back("argon");
  BasisList["cc-pVDZ-DK"].push_back("hydrogen");
  BasisList["cc-pVDZ-DK"].push_back("helium");
  BasisList["cc-pVDZ-DK"].push_back("boron");
  BasisList["cc-pVDZ-DK"].push_back("carbon");
  BasisList["cc-pVDZ-DK"].push_back("nitrogen");
  BasisList["cc-pVDZ-DK"].push_back("oxygen");
  BasisList["cc-pVDZ-DK"].push_back("fluorine");
  BasisList["cc-pVDZ-DK"].push_back("neon");
  BasisList["cc-pVDZ-DK"].push_back("aluminum");
  BasisList["cc-pVDZ-DK"].push_back("silicon");
  BasisList["cc-pVDZ-DK"].push_back("phosphorus");
  BasisList["cc-pVDZ-DK"].push_back("sulfur");
  BasisList["cc-pVDZ-DK"].push_back("chlorine");
  BasisList["cc-pVDZ-DK"].push_back("argon");
  BasisList["cc-pVDZ-DK"].push_back("gallium");
  BasisList["cc-pVDZ-DK"].push_back("germanium");
  BasisList["cc-pVDZ-DK"].push_back("arsenic");
  BasisList["cc-pVDZ-DK"].push_back("selenium");
  BasisList["cc-pVDZ-DK"].push_back("bromine");
  BasisList["cc-pVDZ-DK"].push_back("krypton");
  BasisList["cc-pVDZ"].push_back("hydrogen");
  BasisList["cc-pVDZ"].push_back("helium");
  BasisList["cc-pVDZ"].push_back("lithium");
  BasisList["cc-pVDZ"].push_back("beryllium");
  BasisList["cc-pVDZ"].push_back("boron");
  BasisList["cc-pVDZ"].push_back("carbon");
  BasisList["cc-pVDZ"].push_back("nitrogen");
  BasisList["cc-pVDZ"].push_back("oxygen");
  BasisList["cc-pVDZ"].push_back("fluorine");
  BasisList["cc-pVDZ"].push_back("neon");
  BasisList["cc-pVDZ"].push_back("sodium");
  BasisList["cc-pVDZ"].push_back("magnesium");
  BasisList["cc-pVDZ"].push_back("aluminum");
  BasisList["cc-pVDZ"].push_back("silicon");
  BasisList["cc-pVDZ"].push_back("phosphorus");
  BasisList["cc-pVDZ"].push_back("sulfur");
  BasisList["cc-pVDZ"].push_back("chlorine");
  BasisList["cc-pVDZ"].push_back("argon");
  BasisList["cc-pVDZ"].push_back("calcium");
  BasisList["cc-pVDZ"].push_back("gallium");
  BasisList["cc-pVDZ"].push_back("germanium");
  BasisList["cc-pVDZ"].push_back("arsenic");
  BasisList["cc-pVDZ"].push_back("selenium");
  BasisList["cc-pVDZ"].push_back("bromine");
  BasisList["cc-pVDZ"].push_back("krypton");
  BasisList["cc-pVDZ-RI"].push_back("hydrogen");
  BasisList["cc-pVDZ-RI"].push_back("helium");
  BasisList["cc-pVDZ-RI"].push_back("lithium");
  BasisList["cc-pVDZ-RI"].push_back("beryllium");
  BasisList["cc-pVDZ-RI"].push_back("boron");
  BasisList["cc-pVDZ-RI"].push_back("carbon");
  BasisList["cc-pVDZ-RI"].push_back("nitrogen");
  BasisList["cc-pVDZ-RI"].push_back("oxygen");
  BasisList["cc-pVDZ-RI"].push_back("fluorine");
  BasisList["cc-pVDZ-RI"].push_back("neon");
  BasisList["cc-pVDZ-RI"].push_back("sodium");
  BasisList["cc-pVDZ-RI"].push_back("magnesium");
  BasisList["cc-pVDZ-RI"].push_back("aluminum");
  BasisList["cc-pVDZ-RI"].push_back("silicon");
  BasisList["cc-pVDZ-RI"].push_back("phosphorus");
  BasisList["cc-pVDZ-RI"].push_back("sulfur");
  BasisList["cc-pVDZ-RI"].push_back("chlorine");
  BasisList["cc-pVDZ-RI"].push_back("argon");
  BasisList["cc-pVQZ-DK"].push_back("hydrogen");
  BasisList["cc-pVQZ-DK"].push_back("helium");
  BasisList["cc-pVQZ-DK"].push_back("boron");
  BasisList["cc-pVQZ-DK"].push_back("carbon");
  BasisList["cc-pVQZ-DK"].push_back("nitrogen");
  BasisList["cc-pVQZ-DK"].push_back("oxygen");
  BasisList["cc-pVQZ-DK"].push_back("fluorine");
  BasisList["cc-pVQZ-DK"].push_back("neon");
  BasisList["cc-pVQZ-DK"].push_back("aluminum");
  BasisList["cc-pVQZ-DK"].push_back("silicon");
  BasisList["cc-pVQZ-DK"].push_back("phosphorus");
  BasisList["cc-pVQZ-DK"].push_back("sulfur");
  BasisList["cc-pVQZ-DK"].push_back("chlorine");
  BasisList["cc-pVQZ-DK"].push_back("argon");
  BasisList["cc-pVQZ-DK"].push_back("gallium");
  BasisList["cc-pVQZ-DK"].push_back("germanium");
  BasisList["cc-pVQZ-DK"].push_back("arsenic");
  BasisList["cc-pVQZ-DK"].push_back("selenium");
  BasisList["cc-pVQZ-DK"].push_back("bromine");
  BasisList["cc-pVQZ-DK"].push_back("krypton");
  BasisList["cc-pVQZ-DK"].push_back("scandium");
  BasisList["cc-pVQZ-DK"].push_back("titanium");
  BasisList["cc-pVQZ-DK"].push_back("vanadium");
  BasisList["cc-pVQZ-DK"].push_back("chromium");
  BasisList["cc-pVQZ-DK"].push_back("manganese");
  BasisList["cc-pVQZ-DK"].push_back("iron");
  BasisList["cc-pVQZ-DK"].push_back("cobalt");
  BasisList["cc-pVQZ-DK"].push_back("nickel");
  BasisList["cc-pVQZ-DK"].push_back("copper");
  BasisList["cc-pVQZ-DK"].push_back("zinc");
  BasisList["cc-pVQZ"].push_back("hydrogen");
  BasisList["cc-pVQZ"].push_back("helium");
  BasisList["cc-pVQZ"].push_back("lithium");
  BasisList["cc-pVQZ"].push_back("beryllium");
  BasisList["cc-pVQZ"].push_back("boron");
  BasisList["cc-pVQZ"].push_back("carbon");
  BasisList["cc-pVQZ"].push_back("nitrogen");
  BasisList["cc-pVQZ"].push_back("oxygen");
  BasisList["cc-pVQZ"].push_back("fluorine");
  BasisList["cc-pVQZ"].push_back("neon");
  BasisList["cc-pVQZ"].push_back("sodium");
  BasisList["cc-pVQZ"].push_back("magnesium");
  BasisList["cc-pVQZ"].push_back("aluminum");
  BasisList["cc-pVQZ"].push_back("silicon");
  BasisList["cc-pVQZ"].push_back("phosphorus");
  BasisList["cc-pVQZ"].push_back("sulfur");
  BasisList["cc-pVQZ"].push_back("chlorine");
  BasisList["cc-pVQZ"].push_back("argon");
  BasisList["cc-pVQZ"].push_back("calcium");
  BasisList["cc-pVQZ"].push_back("gallium");
  BasisList["cc-pVQZ"].push_back("germanium");
  BasisList["cc-pVQZ"].push_back("arsenic");
  BasisList["cc-pVQZ"].push_back("selenium");
  BasisList["cc-pVQZ"].push_back("bromine");
  BasisList["cc-pVQZ"].push_back("krypton");
  BasisList["cc-pVQZ"].push_back("scandium");
  BasisList["cc-pVQZ"].push_back("titanium");
  BasisList["cc-pVQZ"].push_back("vanadium");
  BasisList["cc-pVQZ"].push_back("chromium");
  BasisList["cc-pVQZ"].push_back("manganese");
  BasisList["cc-pVQZ"].push_back("iron");
  BasisList["cc-pVQZ"].push_back("cobalt");
  BasisList["cc-pVQZ"].push_back("nickel");
  BasisList["cc-pVQZ"].push_back("copper");
  BasisList["cc-pVQZ"].push_back("zinc");
  BasisList["cc-pVQZ-RI"].push_back("hydrogen");
  BasisList["cc-pVQZ-RI"].push_back("helium");
  BasisList["cc-pVQZ-RI"].push_back("lithium");
  BasisList["cc-pVQZ-RI"].push_back("beryllium");
  BasisList["cc-pVQZ-RI"].push_back("boron");
  BasisList["cc-pVQZ-RI"].push_back("carbon");
  BasisList["cc-pVQZ-RI"].push_back("nitrogen");
  BasisList["cc-pVQZ-RI"].push_back("oxygen");
  BasisList["cc-pVQZ-RI"].push_back("fluorine");
  BasisList["cc-pVQZ-RI"].push_back("neon");
  BasisList["cc-pVQZ-RI"].push_back("sodium");
  BasisList["cc-pVQZ-RI"].push_back("magnesium");
  BasisList["cc-pVQZ-RI"].push_back("aluminum");
  BasisList["cc-pVQZ-RI"].push_back("silicon");
  BasisList["cc-pVQZ-RI"].push_back("phosphorus");
  BasisList["cc-pVQZ-RI"].push_back("sulfur");
  BasisList["cc-pVQZ-RI"].push_back("chlorine");
  BasisList["cc-pVQZ-RI"].push_back("argon");
  BasisList["cc-pVTZ-DK"].push_back("hydrogen");
  BasisList["cc-pVTZ-DK"].push_back("helium");
  BasisList["cc-pVTZ-DK"].push_back("boron");
  BasisList["cc-pVTZ-DK"].push_back("carbon");
  BasisList["cc-pVTZ-DK"].push_back("nitrogen");
  BasisList["cc-pVTZ-DK"].push_back("oxygen");
  BasisList["cc-pVTZ-DK"].push_back("fluorine");
  BasisList["cc-pVTZ-DK"].push_back("neon");
  BasisList["cc-pVTZ-DK"].push_back("aluminum");
  BasisList["cc-pVTZ-DK"].push_back("silicon");
  BasisList["cc-pVTZ-DK"].push_back("phosphorus");
  BasisList["cc-pVTZ-DK"].push_back("sulfur");
  BasisList["cc-pVTZ-DK"].push_back("chlorine");
  BasisList["cc-pVTZ-DK"].push_back("argon");
  BasisList["cc-pVTZ-DK"].push_back("gallium");
  BasisList["cc-pVTZ-DK"].push_back("germanium");
  BasisList["cc-pVTZ-DK"].push_back("arsenic");
  BasisList["cc-pVTZ-DK"].push_back("selenium");
  BasisList["cc-pVTZ-DK"].push_back("bromine");
  BasisList["cc-pVTZ-DK"].push_back("krypton");
  BasisList["cc-pVTZ-DK"].push_back("scandium");
  BasisList["cc-pVTZ-DK"].push_back("titanium");
  BasisList["cc-pVTZ-DK"].push_back("vanadium");
  BasisList["cc-pVTZ-DK"].push_back("chromium");
  BasisList["cc-pVTZ-DK"].push_back("manganese");
  BasisList["cc-pVTZ-DK"].push_back("iron");
  BasisList["cc-pVTZ-DK"].push_back("cobalt");
  BasisList["cc-pVTZ-DK"].push_back("nickel");
  BasisList["cc-pVTZ-DK"].push_back("copper");
  BasisList["cc-pVTZ-DK"].push_back("zinc");
  BasisList["cc-pVTZ"].push_back("hydrogen");
  BasisList["cc-pVTZ"].push_back("helium");
  BasisList["cc-pVTZ"].push_back("lithium");
  BasisList["cc-pVTZ"].push_back("beryllium");
  BasisList["cc-pVTZ"].push_back("boron");
  BasisList["cc-pVTZ"].push_back("carbon");
  BasisList["cc-pVTZ"].push_back("nitrogen");
  BasisList["cc-pVTZ"].push_back("oxygen");
  BasisList["cc-pVTZ"].push_back("fluorine");
  BasisList["cc-pVTZ"].push_back("neon");
  BasisList["cc-pVTZ"].push_back("sodium");
  BasisList["cc-pVTZ"].push_back("magnesium");
  BasisList["cc-pVTZ"].push_back("aluminum");
  BasisList["cc-pVTZ"].push_back("silicon");
  BasisList["cc-pVTZ"].push_back("phosphorus");
  BasisList["cc-pVTZ"].push_back("sulfur");
  BasisList["cc-pVTZ"].push_back("chlorine");
  BasisList["cc-pVTZ"].push_back("argon");
  BasisList["cc-pVTZ"].push_back("calcium");
  BasisList["cc-pVTZ"].push_back("gallium");
  BasisList["cc-pVTZ"].push_back("germanium");
  BasisList["cc-pVTZ"].push_back("arsenic");
  BasisList["cc-pVTZ"].push_back("selenium");
  BasisList["cc-pVTZ"].push_back("bromine");
  BasisList["cc-pVTZ"].push_back("krypton");
  BasisList["cc-pVTZ"].push_back("scandium");
  BasisList["cc-pVTZ"].push_back("titanium");
  BasisList["cc-pVTZ"].push_back("vanadium");
  BasisList["cc-pVTZ"].push_back("chromium");
  BasisList["cc-pVTZ"].push_back("manganese");
  BasisList["cc-pVTZ"].push_back("iron");
  BasisList["cc-pVTZ"].push_back("cobalt");
  BasisList["cc-pVTZ"].push_back("nickel");
  BasisList["cc-pVTZ"].push_back("copper");
  BasisList["cc-pVTZ"].push_back("zinc");
  BasisList["cc-pVTZ-RI"].push_back("hydrogen");
  BasisList["cc-pVTZ-RI"].push_back("helium");
  BasisList["cc-pVTZ-RI"].push_back("lithium");
  BasisList["cc-pVTZ-RI"].push_back("beryllium");
  BasisList["cc-pVTZ-RI"].push_back("boron");
  BasisList["cc-pVTZ-RI"].push_back("carbon");
  BasisList["cc-pVTZ-RI"].push_back("nitrogen");
  BasisList["cc-pVTZ-RI"].push_back("oxygen");
  BasisList["cc-pVTZ-RI"].push_back("fluorine");
  BasisList["cc-pVTZ-RI"].push_back("neon");
  BasisList["cc-pVTZ-RI"].push_back("sodium");
  BasisList["cc-pVTZ-RI"].push_back("magnesium");
  BasisList["cc-pVTZ-RI"].push_back("aluminum");
  BasisList["cc-pVTZ-RI"].push_back("silicon");
  BasisList["cc-pVTZ-RI"].push_back("phosphorus");
  BasisList["cc-pVTZ-RI"].push_back("sulfur");
  BasisList["cc-pVTZ-RI"].push_back("chlorine");
  BasisList["cc-pVTZ-RI"].push_back("argon");
  BasisList["cc-pwCV5Z-DK"].push_back("scandium");
  BasisList["cc-pwCV5Z-DK"].push_back("titanium");
  BasisList["cc-pwCV5Z-DK"].push_back("vanadium");
  BasisList["cc-pwCV5Z-DK"].push_back("chromium");
  BasisList["cc-pwCV5Z-DK"].push_back("manganese");
  BasisList["cc-pwCV5Z-DK"].push_back("iron");
  BasisList["cc-pwCV5Z-DK"].push_back("cobalt");
  BasisList["cc-pwCV5Z-DK"].push_back("nickel");
  BasisList["cc-pwCV5Z-DK"].push_back("copper");
  BasisList["cc-pwCV5Z-DK"].push_back("zinc");
  BasisList["cc-pwCV5Z"].push_back("scandium");
  BasisList["cc-pwCV5Z"].push_back("titanium");
  BasisList["cc-pwCV5Z"].push_back("vanadium");
  BasisList["cc-pwCV5Z"].push_back("chromium");
  BasisList["cc-pwCV5Z"].push_back("manganese");
  BasisList["cc-pwCV5Z"].push_back("iron");
  BasisList["cc-pwCV5Z"].push_back("cobalt");
  BasisList["cc-pwCV5Z"].push_back("nickel");
  BasisList["cc-pwCV5Z"].push_back("copper");
  BasisList["cc-pwCV5Z"].push_back("zinc");
  BasisList["cc-pwCVQZ-DK"].push_back("scandium");
  BasisList["cc-pwCVQZ-DK"].push_back("titanium");
  BasisList["cc-pwCVQZ-DK"].push_back("vanadium");
  BasisList["cc-pwCVQZ-DK"].push_back("chromium");
  BasisList["cc-pwCVQZ-DK"].push_back("manganese");
  BasisList["cc-pwCVQZ-DK"].push_back("iron");
  BasisList["cc-pwCVQZ-DK"].push_back("cobalt");
  BasisList["cc-pwCVQZ-DK"].push_back("nickel");
  BasisList["cc-pwCVQZ-DK"].push_back("copper");
  BasisList["cc-pwCVQZ-DK"].push_back("zinc");
  BasisList["cc-pwCVQZ"].push_back("scandium");
  BasisList["cc-pwCVQZ"].push_back("titanium");
  BasisList["cc-pwCVQZ"].push_back("vanadium");
  BasisList["cc-pwCVQZ"].push_back("chromium");
  BasisList["cc-pwCVQZ"].push_back("manganese");
  BasisList["cc-pwCVQZ"].push_back("iron");
  BasisList["cc-pwCVQZ"].push_back("cobalt");
  BasisList["cc-pwCVQZ"].push_back("nickel");
  BasisList["cc-pwCVQZ"].push_back("copper");
  BasisList["cc-pwCVQZ"].push_back("zinc");
  BasisList["cc-pwCVTZ-DK"].push_back("scandium");
  BasisList["cc-pwCVTZ-DK"].push_back("titanium");
  BasisList["cc-pwCVTZ-DK"].push_back("vanadium");
  BasisList["cc-pwCVTZ-DK"].push_back("chromium");
  BasisList["cc-pwCVTZ-DK"].push_back("manganese");
  BasisList["cc-pwCVTZ-DK"].push_back("iron");
  BasisList["cc-pwCVTZ-DK"].push_back("cobalt");
  BasisList["cc-pwCVTZ-DK"].push_back("nickel");
  BasisList["cc-pwCVTZ-DK"].push_back("copper");
  BasisList["cc-pwCVTZ-DK"].push_back("zinc");
  BasisList["cc-pwCVTZ"].push_back("scandium");
  BasisList["cc-pwCVTZ"].push_back("titanium");
  BasisList["cc-pwCVTZ"].push_back("vanadium");
  BasisList["cc-pwCVTZ"].push_back("chromium");
  BasisList["cc-pwCVTZ"].push_back("manganese");
  BasisList["cc-pwCVTZ"].push_back("iron");
  BasisList["cc-pwCVTZ"].push_back("cobalt");
  BasisList["cc-pwCVTZ"].push_back("nickel");
  BasisList["cc-pwCVTZ"].push_back("copper");
  BasisList["cc-pwCVTZ"].push_back("zinc");
  BasisList["DZ(Dunning)"].push_back("hydrogen");
  BasisList["DZ(Dunning)"].push_back("lithium");
  BasisList["DZ(Dunning)"].push_back("boron");
  BasisList["DZ(Dunning)"].push_back("carbon");
  BasisList["DZ(Dunning)"].push_back("nitrogen");
  BasisList["DZ(Dunning)"].push_back("oxygen");
  BasisList["DZ(Dunning)"].push_back("fluorine");
  BasisList["DZ(Dunning)"].push_back("neon");
  BasisList["DZ(Dunning)"].push_back("aluminum");
  BasisList["DZ(Dunning)"].push_back("silicon");
  BasisList["DZ(Dunning)"].push_back("phosphorus");
  BasisList["DZ(Dunning)"].push_back("sulfur");
  BasisList["DZ(Dunning)"].push_back("chlorine");
  BasisList["DZP(Dunning)"].push_back("hydrogen");
  BasisList["DZP(Dunning)"].push_back("lithium");
  BasisList["DZP(Dunning)"].push_back("boron");
  BasisList["DZP(Dunning)"].push_back("carbon");
  BasisList["DZP(Dunning)"].push_back("nitrogen");
  BasisList["DZP(Dunning)"].push_back("oxygen");
  BasisList["DZP(Dunning)"].push_back("fluorine");
  BasisList["DZP(Dunning)"].push_back("neon");
  BasisList["DZP(Dunning)"].push_back("aluminum");
  BasisList["DZP(Dunning)"].push_back("silicon");
  BasisList["DZP(Dunning)"].push_back("phosphorus");
  BasisList["DZP(Dunning)"].push_back("sulfur");
  BasisList["DZP(Dunning)"].push_back("chlorine");
  BasisList["DZP+Diffuse(Dunning)"].push_back("hydrogen");
  BasisList["DZP+Diffuse(Dunning)"].push_back("boron");
  BasisList["DZP+Diffuse(Dunning)"].push_back("carbon");
  BasisList["DZP+Diffuse(Dunning)"].push_back("nitrogen");
  BasisList["DZP+Diffuse(Dunning)"].push_back("oxygen");
  BasisList["DZP+Diffuse(Dunning)"].push_back("fluorine");
  BasisList["DZP+Diffuse(Dunning)"].push_back("neon");
  BasisList["MIDI(Huzinaga)"].push_back("hydrogen");
  BasisList["MIDI(Huzinaga)"].push_back("helium");
  BasisList["MIDI(Huzinaga)"].push_back("lithium");
  BasisList["MIDI(Huzinaga)"].push_back("beryllium");
  BasisList["MIDI(Huzinaga)"].push_back("boron");
  BasisList["MIDI(Huzinaga)"].push_back("carbon");
  BasisList["MIDI(Huzinaga)"].push_back("nitrogen");
  BasisList["MIDI(Huzinaga)"].push_back("oxygen");
  BasisList["MIDI(Huzinaga)"].push_back("fluorine");
  BasisList["MIDI(Huzinaga)"].push_back("neon");
  BasisList["MIDI(Huzinaga)"].push_back("sodium");
  BasisList["MIDI(Huzinaga)"].push_back("aluminum");
  BasisList["MIDI(Huzinaga)"].push_back("silicon");
  BasisList["MIDI(Huzinaga)"].push_back("phosphorus");
  BasisList["MIDI(Huzinaga)"].push_back("sulfur");
  BasisList["MIDI(Huzinaga)"].push_back("chlorine");
  BasisList["MIDI(Huzinaga)"].push_back("argon");
  BasisList["MIDI(Huzinaga)"].push_back("potassium");
  BasisList["MINI(Huzinaga)"].push_back("hydrogen");
  BasisList["MINI(Huzinaga)"].push_back("helium");
  BasisList["MINI(Huzinaga)"].push_back("lithium");
  BasisList["MINI(Huzinaga)"].push_back("beryllium");
  BasisList["MINI(Huzinaga)"].push_back("boron");
  BasisList["MINI(Huzinaga)"].push_back("carbon");
  BasisList["MINI(Huzinaga)"].push_back("nitrogen");
  BasisList["MINI(Huzinaga)"].push_back("oxygen");
  BasisList["MINI(Huzinaga)"].push_back("fluorine");
  BasisList["MINI(Huzinaga)"].push_back("neon");
  BasisList["MINI(Huzinaga)"].push_back("sodium");
  BasisList["MINI(Huzinaga)"].push_back("magnesium");
  BasisList["MINI(Huzinaga)"].push_back("aluminum");
  BasisList["MINI(Huzinaga)"].push_back("silicon");
  BasisList["MINI(Huzinaga)"].push_back("phosphorus");
  BasisList["MINI(Huzinaga)"].push_back("sulfur");
  BasisList["MINI(Huzinaga)"].push_back("chlorine");
  BasisList["MINI(Huzinaga)"].push_back("argon");
  BasisList["MINI(Huzinaga)"].push_back("potassium");
  BasisList["MINI(Huzinaga)"].push_back("calcium");
  BasisList["MINI(Scaled)"].push_back("hydrogen");
  BasisList["MINI(Scaled)"].push_back("helium");
  BasisList["MINI(Scaled)"].push_back("lithium");
  BasisList["MINI(Scaled)"].push_back("beryllium");
  BasisList["MINI(Scaled)"].push_back("boron");
  BasisList["MINI(Scaled)"].push_back("carbon");
  BasisList["MINI(Scaled)"].push_back("nitrogen");
  BasisList["MINI(Scaled)"].push_back("oxygen");
  BasisList["MINI(Scaled)"].push_back("fluorine");
  BasisList["MINI(Scaled)"].push_back("neon");
  BasisList["MINI(Scaled)"].push_back("sodium");
  BasisList["MINI(Scaled)"].push_back("magnesium");
  BasisList["MINI(Scaled)"].push_back("aluminum");
  BasisList["MINI(Scaled)"].push_back("silicon");
  BasisList["MINI(Scaled)"].push_back("phosphorus");
  BasisList["MINI(Scaled)"].push_back("sulfur");
  BasisList["MINI(Scaled)"].push_back("chlorine");
  BasisList["MINI(Scaled)"].push_back("argon");
  BasisList["MINI(Scaled)"].push_back("potassium");
  BasisList["MINI(Scaled)"].push_back("calcium");
  BasisList["NASAAmesANO"].push_back("hydrogen");
  BasisList["NASAAmesANO"].push_back("boron");
  BasisList["NASAAmesANO"].push_back("carbon");
  BasisList["NASAAmesANO"].push_back("nitrogen");
  BasisList["NASAAmesANO"].push_back("oxygen");
  BasisList["NASAAmesANO"].push_back("fluorine");
  BasisList["NASAAmesANO"].push_back("neon");
  BasisList["NASAAmesANO"].push_back("aluminum");
  BasisList["NASAAmesANO"].push_back("phosphorus");
  BasisList["NASAAmesANO"].push_back("titanium");
  BasisList["NASAAmesANO"].push_back("iron");
  BasisList["NASAAmesANO"].push_back("nickel");
  BasisList["pc-0-aug"].push_back("hydrogen");
  BasisList["pc-0-aug"].push_back("carbon");
  BasisList["pc-0-aug"].push_back("nitrogen");
  BasisList["pc-0-aug"].push_back("oxygen");
  BasisList["pc-0-aug"].push_back("fluorine");
  BasisList["pc-0-aug"].push_back("silicon");
  BasisList["pc-0-aug"].push_back("phosphorus");
  BasisList["pc-0-aug"].push_back("sulfur");
  BasisList["pc-0-aug"].push_back("chlorine");
  BasisList["pc-0"].push_back("hydrogen");
  BasisList["pc-0"].push_back("carbon");
  BasisList["pc-0"].push_back("nitrogen");
  BasisList["pc-0"].push_back("oxygen");
  BasisList["pc-0"].push_back("fluorine");
  BasisList["pc-0"].push_back("silicon");
  BasisList["pc-0"].push_back("phosphorus");
  BasisList["pc-0"].push_back("sulfur");
  BasisList["pc-0"].push_back("chlorine");
  BasisList["pc-1-aug"].push_back("hydrogen");
  BasisList["pc-1-aug"].push_back("carbon");
  BasisList["pc-1-aug"].push_back("nitrogen");
  BasisList["pc-1-aug"].push_back("oxygen");
  BasisList["pc-1-aug"].push_back("fluorine");
  BasisList["pc-1-aug"].push_back("silicon");
  BasisList["pc-1-aug"].push_back("phosphorus");
  BasisList["pc-1-aug"].push_back("sulfur");
  BasisList["pc-1-aug"].push_back("chlorine");
  BasisList["pc-1"].push_back("hydrogen");
  BasisList["pc-1"].push_back("carbon");
  BasisList["pc-1"].push_back("nitrogen");
  BasisList["pc-1"].push_back("oxygen");
  BasisList["pc-1"].push_back("fluorine");
  BasisList["pc-1"].push_back("silicon");
  BasisList["pc-1"].push_back("phosphorus");
  BasisList["pc-1"].push_back("sulfur");
  BasisList["pc-1"].push_back("chlorine");
  BasisList["pc-2-aug"].push_back("hydrogen");
  BasisList["pc-2-aug"].push_back("carbon");
  BasisList["pc-2-aug"].push_back("nitrogen");
  BasisList["pc-2-aug"].push_back("oxygen");
  BasisList["pc-2-aug"].push_back("fluorine");
  BasisList["pc-2-aug"].push_back("silicon");
  BasisList["pc-2-aug"].push_back("phosphorus");
  BasisList["pc-2-aug"].push_back("sulfur");
  BasisList["pc-2-aug"].push_back("chlorine");
  BasisList["pc-2"].push_back("hydrogen");
  BasisList["pc-2"].push_back("carbon");
  BasisList["pc-2"].push_back("nitrogen");
  BasisList["pc-2"].push_back("oxygen");
  BasisList["pc-2"].push_back("fluorine");
  BasisList["pc-2"].push_back("silicon");
  BasisList["pc-2"].push_back("phosphorus");
  BasisList["pc-2"].push_back("sulfur");
  BasisList["pc-2"].push_back("chlorine");
  BasisList["pc-3-aug"].push_back("hydrogen");
  BasisList["pc-3-aug"].push_back("carbon");
  BasisList["pc-3-aug"].push_back("nitrogen");
  BasisList["pc-3-aug"].push_back("oxygen");
  BasisList["pc-3-aug"].push_back("fluorine");
  BasisList["pc-3-aug"].push_back("silicon");
  BasisList["pc-3-aug"].push_back("phosphorus");
  BasisList["pc-3-aug"].push_back("sulfur");
  BasisList["pc-3-aug"].push_back("chlorine");
  BasisList["pc-3"].push_back("hydrogen");
  BasisList["pc-3"].push_back("carbon");
  BasisList["pc-3"].push_back("nitrogen");
  BasisList["pc-3"].push_back("oxygen");
  BasisList["pc-3"].push_back("fluorine");
  BasisList["pc-3"].push_back("silicon");
  BasisList["pc-3"].push_back("phosphorus");
  BasisList["pc-3"].push_back("sulfur");
  BasisList["pc-3"].push_back("chlorine");
  BasisList["pc-4-aug"].push_back("hydrogen");
  BasisList["pc-4-aug"].push_back("carbon");
  BasisList["pc-4-aug"].push_back("nitrogen");
  BasisList["pc-4-aug"].push_back("oxygen");
  BasisList["pc-4-aug"].push_back("fluorine");
  BasisList["pc-4-aug"].push_back("silicon");
  BasisList["pc-4-aug"].push_back("phosphorus");
  BasisList["pc-4-aug"].push_back("sulfur");
  BasisList["pc-4-aug"].push_back("chlorine");
  BasisList["pc-4"].push_back("hydrogen");
  BasisList["pc-4"].push_back("carbon");
  BasisList["pc-4"].push_back("nitrogen");
  BasisList["pc-4"].push_back("oxygen");
  BasisList["pc-4"].push_back("fluorine");
  BasisList["pc-4"].push_back("silicon");
  BasisList["pc-4"].push_back("phosphorus");
  BasisList["pc-4"].push_back("sulfur");
  BasisList["pc-4"].push_back("chlorine");
  BasisList["STO-2G"].push_back("hydrogen");
  BasisList["STO-2G"].push_back("helium");
  BasisList["STO-2G"].push_back("lithium");
  BasisList["STO-2G"].push_back("beryllium");
  BasisList["STO-2G"].push_back("boron");
  BasisList["STO-2G"].push_back("carbon");
  BasisList["STO-2G"].push_back("nitrogen");
  BasisList["STO-2G"].push_back("oxygen");
  BasisList["STO-2G"].push_back("fluorine");
  BasisList["STO-2G"].push_back("neon");
  BasisList["STO-2G"].push_back("sodium");
  BasisList["STO-2G"].push_back("magnesium");
  BasisList["STO-2G"].push_back("aluminum");
  BasisList["STO-2G"].push_back("silicon");
  BasisList["STO-2G"].push_back("phosphorus");
  BasisList["STO-2G"].push_back("sulfur");
  BasisList["STO-2G"].push_back("chlorine");
  BasisList["STO-2G"].push_back("argon");
  BasisList["STO-2G"].push_back("potassium");
  BasisList["STO-2G"].push_back("calcium");
  BasisList["STO-3G"].push_back("hydrogen");
  BasisList["STO-3G"].push_back("helium");
  BasisList["STO-3G"].push_back("lithium");
  BasisList["STO-3G"].push_back("beryllium");
  BasisList["STO-3G"].push_back("boron");
  BasisList["STO-3G"].push_back("carbon");
  BasisList["STO-3G"].push_back("nitrogen");
  BasisList["STO-3G"].push_back("oxygen");
  BasisList["STO-3G"].push_back("fluorine");
  BasisList["STO-3G"].push_back("neon");
  BasisList["STO-3G"].push_back("sodium");
  BasisList["STO-3G"].push_back("magnesium");
  BasisList["STO-3G"].push_back("aluminum");
  BasisList["STO-3G"].push_back("silicon");
  BasisList["STO-3G"].push_back("phosphorus");
  BasisList["STO-3G"].push_back("sulfur");
  BasisList["STO-3G"].push_back("chlorine");
  BasisList["STO-3G"].push_back("argon");
  BasisList["STO-3G"].push_back("potassium");
  BasisList["STO-3G"].push_back("calcium");
  BasisList["STO-3G"].push_back("scandium");
  BasisList["STO-3G"].push_back("titanium");
  BasisList["STO-3G"].push_back("vanadium");
  BasisList["STO-3G"].push_back("chromium");
  BasisList["STO-3G"].push_back("manganese");
  BasisList["STO-3G"].push_back("iron");
  BasisList["STO-3G"].push_back("cobalt");
  BasisList["STO-3G"].push_back("nickel");
  BasisList["STO-3G"].push_back("copper");
  BasisList["STO-3G"].push_back("zinc");
  BasisList["STO-3G"].push_back("gallium");
  BasisList["STO-3G"].push_back("germanium");
  BasisList["STO-3G"].push_back("arsenic");
  BasisList["STO-3G"].push_back("selenium");
  BasisList["STO-3G"].push_back("bromine");
  BasisList["STO-3G"].push_back("krypton");
  BasisList["STO-3G*"].push_back("hydrogen");
  BasisList["STO-3G*"].push_back("helium");
  BasisList["STO-3G*"].push_back("lithium");
  BasisList["STO-3G*"].push_back("beryllium");
  BasisList["STO-3G*"].push_back("boron");
  BasisList["STO-3G*"].push_back("carbon");
  BasisList["STO-3G*"].push_back("nitrogen");
  BasisList["STO-3G*"].push_back("oxygen");
  BasisList["STO-3G*"].push_back("fluorine");
  BasisList["STO-3G*"].push_back("neon");
  BasisList["STO-3G*"].push_back("sodium");
  BasisList["STO-3G*"].push_back("magnesium");
  BasisList["STO-3G*"].push_back("aluminum");
  BasisList["STO-3G*"].push_back("silicon");
  BasisList["STO-3G*"].push_back("phosphorus");
  BasisList["STO-3G*"].push_back("sulfur");
  BasisList["STO-3G*"].push_back("chlorine");
  BasisList["STO-3G*"].push_back("argon");
  BasisList["STO-6G"].push_back("hydrogen");
  BasisList["STO-6G"].push_back("helium");
  BasisList["STO-6G"].push_back("lithium");
  BasisList["STO-6G"].push_back("beryllium");
  BasisList["STO-6G"].push_back("boron");
  BasisList["STO-6G"].push_back("carbon");
  BasisList["STO-6G"].push_back("nitrogen");
  BasisList["STO-6G"].push_back("oxygen");
  BasisList["STO-6G"].push_back("fluorine");
  BasisList["STO-6G"].push_back("neon");
  BasisList["STO-6G"].push_back("sodium");
  BasisList["STO-6G"].push_back("magnesium");
  BasisList["STO-6G"].push_back("aluminum");
  BasisList["STO-6G"].push_back("silicon");
  BasisList["STO-6G"].push_back("phosphorus");
  BasisList["STO-6G"].push_back("sulfur");
  BasisList["STO-6G"].push_back("chlorine");
  BasisList["STO-6G"].push_back("argon");
  BasisList["STO-6G"].push_back("potassium");
  BasisList["STO-6G"].push_back("calcium");
  BasisList["STO-6G"].push_back("scandium");
  BasisList["STO-6G"].push_back("titanium");
  BasisList["STO-6G"].push_back("vanadium");
  BasisList["STO-6G"].push_back("chromium");
  BasisList["STO-6G"].push_back("manganese");
  BasisList["STO-6G"].push_back("iron");
  BasisList["STO-6G"].push_back("cobalt");
  BasisList["STO-6G"].push_back("nickel");
  BasisList["STO-6G"].push_back("copper");
  BasisList["STO-6G"].push_back("zinc");
  BasisList["STO-6G"].push_back("gallium");
  BasisList["STO-6G"].push_back("germanium");
  BasisList["STO-6G"].push_back("arsenic");
  BasisList["STO-6G"].push_back("selenium");
  BasisList["STO-6G"].push_back("bromine");
  BasisList["STO-6G"].push_back("krypton");
  BasisList["TZ(Dunning)"].push_back("hydrogen");
  BasisList["TZ(Dunning)"].push_back("lithium");
  BasisList["TZ(Dunning)"].push_back("beryllium");
  BasisList["TZ(Dunning)"].push_back("boron");
  BasisList["TZ(Dunning)"].push_back("carbon");
  BasisList["TZ(Dunning)"].push_back("nitrogen");
  BasisList["TZ(Dunning)"].push_back("oxygen");
  BasisList["TZ(Dunning)"].push_back("fluorine");
  BasisList["TZ(Dunning)"].push_back("neon");
}
